@@ -32,28 +32,30 @@ DIRECTORY = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))
 IS_INSTALLED = not os.path.exists(os.path.join(DIRECTORY,"ChangeLog"))
 IS_DEVELOPMENT_VERSION = True
 
-# Check the profile directory to prevent crashes when saving settings, etc
-USER_DIR = os.path.join(
-                os.environ.get(
-                    "XDG_CONFIG_HOME",
-    			    os.path.join(os.environ['HOME'], ".config")),
-    			"conduit"
-    			)
-if not os.path.exists(USER_DIR):
-    os.makedirs(USER_DIR)
+#test the existance of some compulsory directories
+CONFIG_DIR = os.environ.get("XDG_CONFIG_HOME", os.path.join(os.environ['HOME'], ".config"))
+AUTOSTART_FILE_DIR = os.path.join(CONFIG_DIR,	"autostart")
+USER_DIR = os.path.join(CONFIG_DIR,	"conduit")
+for d in (AUTOSTART_FILE_DIR, USER_DIR):
+    if not os.path.exists(d):
+        os.makedirs(d)
 
 if IS_INSTALLED:
     from defs import *
     if not PYTHONDIR in sys.path:
         sys.path.insert(0, PYTHONDIR)
 else:
-    VERSION =                   "0.3.13.1"
+    VERSION =                   "0.3.17"
     LOCALE_DIR =                os.path.join(DIRECTORY, "po")
     SHARED_DATA_DIR =           os.path.join(DIRECTORY, "data")
-    GLADE_FILE =                os.path.join(DIRECTORY, "data","conduit.glade")
     SHARED_MODULE_DIR =         os.path.join(DIRECTORY, "conduit", "modules")
-    BROWSER_IMPL =              "gtkmozembed"   #{gtkmozembed, webkit, system}
-    SETTINGS_IMPL =             "GConf"         #{GConf,Python}
+    DESKTOP_FILE_DIR =          os.path.join(DIRECTORY, "data")
+                                #{GIO, Python}
+    FILE_IMPL =                 os.environ.get("CONDUIT_FILE_IMPL","GIO")
+                                #{gtkmozembed, webkit, system}
+    BROWSER_IMPL =              os.environ.get("CONDUIT_BROWSER_IMPL","webkit")
+                                #{GConf,Python}
+    SETTINGS_IMPL =             os.environ.get("CONDUIT_SETTINGS_IMPL","GConf")
 
 import Globals
 GLOBALS = Globals.Globals()
